@@ -1,8 +1,8 @@
 ;;; func-menu.el         --- Jump to a function within a buffer.
 ;;;
 ;;; David Hughes <d.hughes@videonetworks.com>
-;;; Last Modified: David Hughes 7th September 1998
-;;; Version: 2.61
+;;; Last Modified: David Hughes 9th November 1998
+;;; Version: 2.63
 ;;; Keywords: tools, c, lisp
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -82,7 +82,7 @@
 ;;; Speedup for fume-cc-inside-comment
 ;;; Peter Pezaris <pez@dwwc.com>
 ;;;
-;;; Made menu placement more flexible
+;;; Made menu placement more flexible and rewrote doc strings
 ;;; Bob Weiner <weiner@altrasoft.com>
 ;;;
 ;;; Fortran90 regexp
@@ -240,7 +240,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;  Environment Initialisation  ;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defconst fume-version "2.61")
+(defconst fume-version "2.63")
 
 (defconst fume-developer "David Hughes <d.hughes@videonetworks.com>")
 
@@ -249,7 +249,7 @@
   (sit-for 0)
   (display-message
    'no-log
-   (format "Func-Menu version %s,  1998 %s" fume-version fume-developer)))
+   (format "Func-Menu version %s, ,A)(B 1998 %s" fume-version fume-developer)))
 
 (defconst fume-running-xemacs (string-match "XEmacs\\|Lucid" emacs-version))
 
@@ -298,7 +298,7 @@ Associates the function with the current load file, if any."
     ;; Win-Emacs doesn't have this
     (defun shrink-window-if-larger-than-buffer (&optional window reqd-height)
       "Shrink WINDOW to the smallest no of lines needed to display its buffer,
-or to optional REQUIRED-HEIGHT if and only if that is larger. Does nothing if
+or to optional REQUIRED-HEIGHT if and only if that is larger.  Does nothing if
 the buffer contains more lines than the present window height."
       (interactive)
       (let* ((OriginalWindow (selected-window))
@@ -433,47 +433,47 @@ the buffer contains more lines than the present window height."
   :group 'lisp)
 
 (defcustom fume-auto-position-popup t
-  "*Set to nil if you don't want the menu to appear in the corner of the window
-in which case it will track the mouse position instead."
+  "*Setting of t (default) means popup the Function menu at the mouse cursor,
+nil means at a window corner."
   :type 'boolean
   :group 'fume)
 
 (fume-defvar-local fume-display-in-modeline-p t
-  "*Set to nil if you don't want the function name appearing in the modeline.
-If your modeline is already full, then you can set this variable to something
-besides nil or t and the current function will replace the normal
-modeline-buffer-identification
+  "*Setting of t (default) means display the function name in the modeline,
+nil disables.
+Non-nil, non-t setting replaces the normal `modeline-buffer-identification'
+which is useful when the modeline display is already full.
 
-Note, this is a buffer-local variable.")
+This is a buffer-local variable.")
 
 (defvar fume-buffer-name "*Function List*"
-  "Name of buffer used to list functions when fume-list-functions called")
+  "Name of buffer used to list functions when `fume-list-functions' is called")
 
 (defcustom fume-menubar-menu-name "Functions"
-  "*Set this to the string you want to appear in the menubar"
+  "*Name of the menubar menu which displays current buffer function definitions"
   :type 'string
   :group 'fume)
 
 ;;; Bob Weiner <weiner@altrasoft.com>
 (defvar fume-menu-path nil
-  "Menubar menu under which the function menu should be installed.
-Nil means install it on the menubar itself.  Otherwise, it should be a list
-of strings, each string names a successively deeper menu under which the
-new menu should be located.")
+  "Path to the menubar menu under which the function menu should be installed.
+Nil (default) means install it on the menubar itself.  Otherwise, this should
+be a list of strings, each of which names a successively deeper menu under
+which the new menu should be located.")
 
 (defcustom fume-menubar-menu-location "Buffers"
-  "*Set this nil if you want the menu to appear last on the menubar.
-Otherwise set this to the menu you want \"Functions\" to appear in front of."
+  "*Name of menu before which function menu should appear (default=\"Buffers\").
+Nil means display it after the last non-right-justified menubar item."
   :type '(choice (const :tag "Last" nil) (string :format "%v"))
   :group 'fume)
 
 (defcustom fume-max-items 24
-  "*Maximum number of elements in a function (sub)menu."
+  "*Maximum number of elements in a function menu or submenu (default = 24)."
   :type 'integer
   :group 'fume)
 
 (defcustom fume-fn-window-position 3
-  "*Number of lines from top of window at which to show function.
+  "*Number of lines from top of window at which to show a function (default = 3)
 If nil, display function start from the centre of the window."
   :type '(choice (const :tag "Center" nil) integer)
   :group 'fume)
@@ -493,46 +493,48 @@ Methods currently supported:
   :group 'fume)
 
 (defcustom fume-scanning-message "Scanning buffer... (%3d%%)"
-  "*Set to nil if you don't want progress messages during manual scanning
-of the buffer."
+  "*Message string format displayed during manual buffer function scans.
+Nil means inhibit such messages."
   :type '(choice (const :tag "None" nil) string)
   :group 'fume)
 
 (defcustom fume-rescanning-message nil
-  "*Set to non-nil if you want progress messages during automatic scanning
-of the buffer. For example \"Re-Scanning buffer...\""
+  "*Message string format displayed during automatic buffer function scans.
+For example, \"Re-Scanning buffer...\".  Nil (default) means inhibit such
+messages."
   :type '(choice (const :tag "None" nil) string)
   :group 'fume)
 
 (defvar fume-rescan-trigger-counter-buffer-size 10000
-  "Used to tune the frequency of automatic checks on the buffer.
-The function fume-rescan-buffer-trigger only works whenever the value of the
-variable fume-rescan-trigger-counter reaches zero, whereupon it gets reset to
-the maximum of a) buffer-size/fume-rescan-trigger-counter-buffer-size
-            or b) fume-rescan-trigger-counter-min")
+  "Used to tune the frequency of automatic function scans of the buffer
+(default = 10000).
+The function `fume-rescan-buffer-trigger' executes only when the value of the
+variable `fume-rescan-trigger-counter' reaches zero, whereupon it gets reset
+to the maximum of a) buffer-size/`fume-rescan-trigger-counter-buffer-size'
+               or b) `fume-rescan-trigger-counter-min'.")
 
 (defvar fume-rescan-trigger-counter-min 50
-  "Used to tune the frequency of automatic checks on the buffer.
-The function fume-rescan-buffer-trigger only works whenever the value of the
-variable fume-rescan-trigger-counter reaches zero, whereupon it gets reset to
-the maximum of a) buffer-size/fume-rescan-trigger-counter-buffer-size
-            or b) fume-rescan-trigger-counter-min")
+  "Used to tune the frequency of automatic function scans of the buffer
+(default = 50).
+The function `fume-rescan-buffer-trigger' executes only when the value of the
+variable `fume-rescan-trigger-counter' reaches zero, whereupon it gets reset
+to the maximum of a) buffer-size/`fume-rescan-trigger-counter-buffer-size'
+               or b) `fume-rescan-trigger-counter-min'.")
 
 (fume-defvar-local
  fume-sort-function 'fume-sort-by-name
- "*The function to use for sorting the function menu.
+ "*The function used to sort the function menu entries
+(default = fume-sort-by-name).
+Nil means display in order of occurrence in the buffer; this is faster since
+no sorting is done.
 
-Set this to nil if you don't want any sorting (faster).
-The items in the menu are then presented in the order they were found
-in the buffer.
-
-The function should take two arguments and return T if the first
-element should come before the second.  The arguments are cons cells;
-(NAME . POSITION).  Look at 'fume-sort-by-name' for an example.")
+The function should take two arguments and return t if the first
+element should appear before the second.  The arguments are cons cells:
+\(NAME . POSITION).  See `fume-sort-by-name' for an example.")
 
 (fume-defvar-local
  fume-rescan-buffer-hook nil
- "*Buffer local hook to call at the end of each buffer rescan")
+ "*Buffer local hook to call at the end of each buffer rescan.")
 
 ;;; This hook is provided for outl-mouse and must not be made buffer local as
 ;;; this appears to break outl-mouse for some reason.
@@ -544,14 +546,15 @@ element should come before the second.  The arguments are cons cells;
 ;;; Marc Paquette <Marc.Paquette@Softimage.COM>
 ;;;
 (defvar fume-no-prompt-on-valid-default nil
-  "*Set non-nil if 'fume-prompt-function-goto' should jump without prompting
-when a valid default exists.")
+  "*Non-nil means `fume-prompt-function-goto' should jump to default function
+definition without prompting.
+Default value is nil.")
 
 ;;; Idea from Mark Gates <mgates@ncsa.uiuc.edu>
 ;;;
 (defvar fume-goto-function-hook nil
-  "*If non-nil, this should be a function taking POS. This function will be
-called if fume-fn-window-position is nil or not a valid number.")
+  "*Function of with one argument (position)
+called if `fume-fn-window-position' is nil or invalid. Default is nil.")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;  Buffer local variables  ;;;;;;;;;;;;;;;;;;;;;;;;
@@ -559,13 +562,12 @@ called if fume-fn-window-position is nil or not a valid number.")
 
 (fume-defvar-local
  fume-auto-rescan-buffer-p t
- "Buffer local variable which if non-nil permits automatic buffer rescanning
-by func-menu.
+ "Buffer local variable which if t (default) enables automatic buffer rescanning
 
 Usage:
-By default, fume-auto-rescan-buffer-p is set to non-nil. If you feel that
-a given mode 'foo' is becoming too slow as a result of automatic rescanning
-by func-menu, then do something along the lines of the following:
+By default, `fume-auto-rescan-buffer-p' is set to t. If a particular
+major-mode slows down too much as a result of automatic rescanning
+by func-menu, add someting like the following:
 
    (defun remove-func-menu-auto-rescan ()
       (setq fume-auto-rescan-buffer-p nil))
@@ -574,38 +576,41 @@ by func-menu, then do something along the lines of the following:
 
 (fume-defvar-local
  fume-funclist nil
- "The latest list of function names in the buffer")
+ "The latest list of function names in the buffer.")
 
 (fume-defvar-local
  fume-function-name-regexp nil
- "The keywords to show in a menu")
+ "Regexp which matches names within function definitions.
+These names are displayed in the function menu.")
 
 (fume-defvar-local
  fume-find-next-function-name-method nil
- "The function to use to find the next function name in the buffer")
+ "The function to use to find the next function name in the buffer.")
 
 (fume-defvar-local
  fume-modeline-funclist nil
- "The latest list of function names in the buffer to display in the modeline")
+ "The latest list of function names in the buffer.
+If point is within a function definition, a name from this list may be
+displayed in the modeline.")
 
 (fume-defvar-local
  fume-funclist-dirty-p nil
- "Flags whether the buffer is in need of a fresh scan")
+ "Flags whether the buffer is in need of a fresh scan.")
 
 (fume-defvar-local
  fume-rescan-inhibit-p nil
- "Internal variable only. DO NOT TOUCH.")
+ "Internal variable only.  DO NOT TOUCH.")
 
 (fume-defvar-local
  fume-rescan-trigger-counter 0
- "Used in large buffers to optimise checking frequency")
+ "Used in large buffers to optimise automatic function rescanning frequency.")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;  Mode specific regexp's and hooks  ;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; Every fume-function-name-regexp-<language> should uniquely identify a
-;;; function for that certain language.
+;;; function for that language.
 
 ;;; Lisp
 ;;;
@@ -617,7 +622,7 @@ by func-menu, then do something along the lines of the following:
                                         ;  for the construct |    (defun foo ()
    "(\\(def[^vc][a-z]*\\)"              ; Allow (def* except (defvar, (defconst
    "\\s-+"                              ; At least one whitespace
-   "'?[#:?%@!/A-Za-z0-9_+<>-]+"         ; Allow (defalias 'foo 'bar)
+   "'?[#:?%@!*/A-Za-z0-9_+<>-]+"        ; Allow (defalias 'foo 'bar)
    "\\s-*"                              ; Whitespace
    "\\(nil\\|(\\)"                      ; nil or (arg list
    )
@@ -702,12 +707,37 @@ by func-menu, then do something along the lines of the following:
 ;;; John Turner <turner@xdiv.lanl.gov>
 (defvar fume-function-name-regexp-fortran90
   (concat
-   ;; type specs
-   "[a-zA-Z0-9*]*\\s-*"
-   ;; function or subroutine
-   "\\(entry\\|ENTRY\\|function\\|FUNCTION\\|module\\|MODULE\\|subroutine\\|SUBROUTINE\\)\\s-*"
-   )
-  "Expression to get Fortran 90 function, module and subroutine names")
+   ;; Start of big "Or" clause.
+   "\\("
+   ;; Modules -- must start at beginning of line -- this eliminates
+   ;; "module procedure" statements, which are indented.
+   "^[Mm][Oo][Dd][Uu][Ll][Ee]\\s-*"
+   ;; Or.
+   "\\|"
+   ;; Derived type definitions. This makes use of my convention to
+   ;; never leave a space between "type" and "(" when I actually use
+   ;; a derived type.
+   "^\\s-*[Tt][Yy][Pp][Ee][^(]\\s-*"
+   ;; Or.
+   "\\|"
+   ;; White space at beginning.
+   "^\\s-*"
+   ;; Type specs -- not used, because it would also include "end 
+   ;; function" lines and I don't use type specs before function 
+   ;; statements anyway. Uncomment this line if you want that behavior.
+   ;; "[a-zA-Z0-9*]*"
+   ;;
+   ;; Entry, function, subroutine, program.
+   "\\("
+   "[Ee][Nn][Tt][Rr][Yy]\\|"
+   "[Ff][Uu][Nn][Cc][Tt][Ii][Oo][Nn]\\|"
+   "[Ss][Uu][Bb][Rr][Oo][Uu][Tt][Ii][Nn][Ee]\\|"
+   "[Pp][Rr][Oo][Gg][Rr][Aa][Mm]"
+   "\\)\\s-*"
+   ;; End of big "Or" clause.
+   "\\)"
+  )
+  "Expression to get Fortran 90 module, type, function, and subroutine names.")
 
 ;;; Modula
 (defvar fume-function-name-regexp-modula
@@ -875,12 +905,12 @@ by func-menu, then do something along the lines of the following:
   (cons "^[ \t]*\\([pP][rR][oO][cC][eE][dD][uU][rR][eE]\\|[fF][uU][nN][cC][tT][iI][oO][nN]\\|[tT][aA][sS][kK][ \t\n]*[bB][oO][dD][yY]\\)[ \n\t]+\\([a-zA-Z0-9_]+\\|\"[^\"]\"\\)" 2)
   "Expression to find declaration of Ada function")
 
-;;; ignore prototypes, 'renames', 'is new' to eliminate clutter
+;;; ignore prototypes, `renames', `is new' to eliminate clutter
 ;;;
 ;;; Scott Evans <gse@ocsystems.com>
 (defvar fume-function-name-regexp-ada-ignore
   "[ \n\t]*\\(([^()]+)[ \n\t]*\\)?\\(return[ \t\n]+[^ \t\n;]+[ \n\t]*\\)?\\(;\\|is[ \n\t]+new[ \n\t]\\|renames\\)"
-  "ignore if ada function name matches this string")
+  "Ignore if ada function name matches this string")
 
 ;;; Makefiles
 ;;;
@@ -888,11 +918,12 @@ by func-menu, then do something along the lines of the following:
 ;;; Paul Filipski & Anthony Girardin <{filipski,girardin}@blackhawk.com>
 (defvar fume-function-name-regexp-make
   "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\.\\|\\_\\|\\/\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
-  "Expression to get makefile target names")
-;; The original version from D.Hughes has this uncommented, but XEmacs 20.4
-;; has it commented and it is way too slow on non-trivial Makefiles so I'm
-;; commenting it back out.  -slb Aug 6, 1998.
-;; (add-hook 'makefile-mode-hook 'fume-add-menubar-entry)
+  "Expression to get makefile target names
+
+Add the following line to your .emacs if you want Makefile support. Note, this
+can be very slow for large or non-trivial Makefiles.
+
+(add-hook 'makefile-mode-hook 'fume-add-menubar-entry)")
 
 ;;; Directory Listings
 ;;;
@@ -909,7 +940,6 @@ by func-menu, then do something along the lines of the following:
   "^\\(function\\|procedure\\)[ \t]+\\([_a-zA-Z][_a-zA-Z0-9]*\\)"
   "Expression to get function/procedure names in pascal.")
 
-
 ;;; Fame
 ;;;
 ;;; Cooper Vertz <cooper@prod2.imsi.com>
@@ -917,7 +947,6 @@ by func-menu, then do something along the lines of the following:
   "^\\(function\\|procedure\\)[ \t]+\\([#\\$%_a-zA-Z][#\\$%_a-zA-Z0-9]*\\)"
   "Expression to get function/procedure names in fame.")
 
-
 ;;; Verilog
 ;;;
 ;;; Matt Sale <mdsale@icdc.delcoelect.com>
@@ -1139,8 +1168,10 @@ by func-menu, then do something along the lines of the following:
                                 (format "%s %s"
                                         name
                                         (buffer-substring beg (point))))))))
-            ;; kludge to avoid 'void' etc in menu
-            (if (string-match "^void$\\|^if$\\|^switch$\\|^while$" name)
+            ;; kludge to avoid `void' etc in menu
+            (if (string-match
+                "\\`\\(void\\|if\\|else if\\|else\\|switch\\|for\\|while\\)\\'"
+		name)
                 (fume-find-next-c-function-name buffer)
               (cons name beg)))))))
 
@@ -1216,7 +1247,7 @@ by func-menu, then do something along the lines of the following:
               (setq beg (point))
               (forward-sexp)
               (setq name (buffer-substring beg (point)))
-              ;; kludge to avoid 'void' in menu
+              ;; kludge to avoid `void' in menu
               (if (string-match "^void\\s-*" name)
                   (fume-find-next-function-name buffer)
                 (cons name beg))))))))
@@ -1249,7 +1280,7 @@ by func-menu, then do something along the lines of the following:
               ;; would ignore "notify()" since it contained "if".
               (or
                (string-match
-                "\\`\\(if\\|switch\\|catch\\|for\\|while\\|synchronized\\)\\'"
+                "\\`\\(if\\|else if\\|else\\|switch\\|catch\\|for\\|while\\|synchronized\\)\\'"
                 str)
                ;; These constructs look like method definitions but are not
                (cons str beg)))
@@ -1594,7 +1625,7 @@ If no connection is in this alist for a given mode, a default method is used")
      (nth 0 (window-pixel-edges))
      (nth 1 (window-pixel-edges)))))
 
-;;; Sets 'fume-function-name-regexp' to something appropriate for the current
+;;; Sets `fume-function-name-regexp' to something appropriate for the current
 ;;; mode for this buffer.
 ;;;
 (defun fume-set-defaults ()
@@ -2088,18 +2119,25 @@ If optional arg POPMENU is non-nil, brings up the function-menu."
 
 ;;; Interface for Key bindings
 ;;;
-(defun function-menu (&optional use-menubar return-only)
-  "Pop up a menu of functions for selection with the mouse.
-Jumps to the selected function.  A mark is set at the old position,
-so you can easily go back with C-u \\[set-mark-command].
+;;;###autoload
+(defun function-menu (&optional use-menubar return-only menu-item-function)
+  "Pop up a menu of buffer local functions and related commands.
+Each function menu entry jumps to its named function.  Prior to a jump, a
+mark is set so that {C-u \\[set-mark-command]} will move point back to the
+old location.
 
-With a prefix arg adds the menu to the current menubar.
-Optional second argument, RETURN-ONLY if non-nil simply returns
-the basic menu of functions."
+With optional prefix argument USE-MENUBAR, add the menu to the current
+menubar.  With optional second argument RETURN-ONLY, return the menu
+of functions but do not display it.
+
+With optional third argument MENU-ITEM-FUNCTION, use this as the function
+called by each menu item (default = 'fume-goto-function).  This function
+must take two arguments, function menu item name (a string) and the position
+\(an integer) within the buffer to leave point when displaying this menu item."
   (interactive "P")
 
   (setq use-menubar
-        (and use-menubar fume-running-xemacs fume-not-tty current-menubar))
+        (and use-menubar fume-running-xemacs fume-not-tty current-menubar t))
 
   (catch 'no-functions
     (or (fume-set-defaults)
@@ -2123,13 +2161,14 @@ the basic menu of functions."
     ;; Function name in modeline
     (fume-maybe-install-modeline-feature)
 
+    (or menu-item-function (setq menu-item-function 'fume-goto-function))
     ;; The rest of this routine works only for (Lucid) XEmacs
     (cond (fume-running-xemacs
            ;; Create the menu
            (let* ((count 0)
                   (index-method
-                   (intern (format "fume-index-sublist-method-%d"
-                                   fume-index-method)))
+                   (intern-soft (format "fume-index-sublist-method-%d"
+                                        fume-index-method)))
                   function-menu
                   (function-menu-items
                    (mapcar
@@ -2143,7 +2182,7 @@ the basic menu of functions."
                           (lambda (menu)
                             (vector
                              (fume-trim-string (format "%s" (car menu)) "&")
-                             (list 'fume-goto-function (car menu) (cdr menu))
+                             (list menu-item-function (car menu) (cdr menu))
                              t)))
                          sublist))))
                     (fume-split fume-funclist fume-max-items))))
@@ -2203,7 +2242,7 @@ the basic menu of functions."
              function-menu-items)))))
 
 (defun fume-mouse-function-goto (event)
-  "Goto function clicked on or prompt in minibuffer (with completion)."
+  "Goto function clicked on or prompt with completion in the minibuffer."
   (interactive "@e")
   (let ((orig-pos (point)))
     (goto-char (event-point event))
@@ -2226,9 +2265,10 @@ the basic menu of functions."
 ;;; David Hughes <d.hughes@videonetworks.com>
 ;;;
 (defun fume-prompt-function-goto (&optional other-window-p prompt)
-  "Goto function prompted for in minibuffer (with completion).
-With prefix arg, jumps to function in a different window.
-PROMPT (useful for wrapper functions) must be a format string with two %s's"
+  "Goto a function prompted for with completion in the minibuffer.
+With optional prefix argument OTHER-WINDOW-P, jump to the function in a
+different window.  PROMPT (useful for wrapper functions) must be a format
+string with two `%s' elements."
   (interactive "P")
   (let* ((default-name (fume-what-looking-at t))
          (OrigBuffer (current-buffer))
@@ -2375,15 +2415,9 @@ PROMPT (useful for wrapper functions) must be a format string with two %s's"
       (let ((srcbuffer (current-buffer)))
         (set-buffer (get-buffer-create fume-buffer-name))
         (let (buffer-read-only) (erase-buffer))
-        (use-local-map fume-list-mode-map)
-        (setq buffer-read-only t
-              mode-name "Func-Menu"
-              major-mode 'fume-list-mode
-              fume-list-srcbuffer srcbuffer
-              fume-list-reused-win-p (not (one-window-p)))
-        (if fume-not-tty
-            (setq mode-motion-hook 'mode-motion-highlight-symbol))
-        (run-hooks 'fume-list-mode-hook)))
+	(fume-list-mode)
+        (setq fume-list-srcbuffer srcbuffer
+              fume-list-reused-win-p (not (one-window-p)))))
     (or fume-funclist (fume-rescan-buffer))
     (if fume-funclist
         (mapcar
@@ -2409,6 +2443,19 @@ PROMPT (useful for wrapper functions) must be a format string with two %s's"
                   (beginning-of-line)))
            (fume-list-functions-help)))))
 
+(defun fume-list-mode ()
+  "Major mode for jumping from a list of buffer functions to a function
+definition.
+
+\\{fume-list-mode-map}"
+  (use-local-map fume-list-mode-map)
+  (setq buffer-read-only t
+	mode-name "Func-Menu"
+	major-mode 'fume-list-mode)
+  (if fume-not-tty
+      (setq mode-motion-hook 'mode-motion-highlight-symbol))
+  (run-hooks 'fume-list-mode-hook))
+
 (provide 'func-menu)
 
 ;;; end of file
