@@ -74,6 +74,24 @@ This is relavent for Solaris and, perhaps, other systems which have
   :type 'boolean
   :group 'man)
 
+(defcustom Manual-bold-twocolumn-compatibility-regexp
+  (if (featurep 'mule)
+      "\\cj"
+    nil)
+"Regexp to matche bold two-column character.
+
+For compatibility with Japanese nroff, which puts one backspace in for
+each nominal column to create a bold character.  Ie, a bold kanji
+looks like \"K^H^Hk\".  Other multibyte languages can be added to the
+regexp if necessary by replacing the \"\cj\" with a group of alternative
+character classes (such as \"\ck\" for Korean and \"\cc\" for Chinese).
+
+This option may go away if it becomes clear how to do the right thing
+automatically without it."
+           :group 'manual
+	   :type '(choice regexp
+			  (const :tag "Off" nil)))
+
 ;;Here is information on RosettaMan, from Neal.Becker@comsat.com (Neal Becker):
 
 ;;RosettaMan is a filter for UNIX manual pages.  It takes as input man
@@ -352,6 +370,21 @@ potentially taking a long time."
 	  (delete-region (+ (point) 1) (match-end 0))
 	  (forward-char 1))
 	(set-extent-face (make-extent s (point)) 'man-bold)))
+
+    ;; Kludge to make Japanese manual happy.
+    ;; Usually width of Japanese characters is same as two ASCII
+    ;; characters at terminal.  Therefore, two \b is used.
+    ;; Probably Chinese and Korean version is the same, but I don't know.
+    (when Manual-bold-twocolumn-compatibility-regexp
+      (goto-char (point-min))
+      (while (re-search-forward
+	      (concat "\\("
+		      Manual-bold-twocolumn-compatibility-regexp
+		      "\\)\b\b\\1")
+	      nil t)
+	(delete-region (match-end 1) (point))
+	(set-extent-face (make-extent (1- (point)) (point)) 'man-bold)))
+
     ;;
     ;; hack bullets: o^H+ --> +
     (goto-char (point-min))
